AlertInfo class

Represents alert information with a title and message.

This class is used to encapsulate user-friendly error messages that can be displayed as alerts to the user.

Constructors

AlertInfo({required String title, required String message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message or description of the alert.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the alert.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited