ApiErrorMessage class

A collection of predefined error messages that can be used throughout the application to provide consistent and descriptive error messages to the user during API calls.

Constructors

ApiErrorMessage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultErrorTitle → const String
Default title for error messages.
httpErrorMessage → const String
Message indicating the server is currently unavailable.
invalidFormat → const String
Message indicating an invalid format error.
noInternet → const String
Title indicating no internet connection.
noInternetMessage → const String
Message suggesting the user to check their internet connection.
requestTimeoutMessage → const String
Message indicating the server took too long to respond, suggesting potential connectivity issues or server problems.
requestTimeoutTitle → const String
Title indicating a request timeout.
socketException → const String
A generic error message for unexpected issues.
somethingWentWrong → const String
A generic message indicating something went wrong.
unauthorisedMessage → const String
Message indicating the session has expired and suggesting the user to log in again.
unauthorisedTitle → const String
Title indicating an unauthorized access or expired session.
underMaintenanceMessage → const String
Message indicating the system is down for scheduled maintenance.
underMaintenanceTitle → const String
Title indicating the system is under maintenance.