UploadDocumentObj class

Represents the information required for uploading a document.

This class is used in conjunction with the APIRequestInfoObj class for making multipart API requests. It specifies the key for the document and a list of paths to the documents to be uploaded.

Constructors

UploadDocumentObj({String docKey = "", List<String> docPathList = const []})
Constructor for the UploadDocumentObj class.

Properties

docKey String
Key for the document in the multipart request.
getter/setter pair
docPathList List<String>
List of paths to the documents to be uploaded.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited