UploadDocumentObj constructor
Constructor for the UploadDocumentObj class.
Initializes the class with the provided key and list of document paths.
Implementation
UploadDocumentObj({
this.docKey = "",
this.docPathList = const [],
});
Constructor for the UploadDocumentObj class.
Initializes the class with the provided key and list of document paths.
UploadDocumentObj({
this.docKey = "",
this.docPathList = const [],
});