APIRequestInfoObj class
Represents the information required for an API request.
This class encapsulates all the necessary details needed to make an API call. It includes the type of HTTP request (GET, POST, PUT, DELETE), the request URL, any parameters to be sent with the request, headers, documents for multipart requests, the name of the service being called, and a timeout duration for the request.
Constructors
-
APIRequestInfoObj({HTTPRequestType requestType = HTTPRequestType.post, Map<
String, dynamic> ? parameter, Map<String, String> ? headers, List<UploadDocumentObj> docList = const [], required String url, String serviceName = "", int timeSecond = 90}) -
Constructor for the
APIRequestInfoObjclass.
Properties
-
docList
↔ List<
UploadDocumentObj> -
List of documents to be uploaded in case of a multipart request.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, String> ? -
Headers to be included in the API request.
getter/setter pair
-
parameter
↔ Map<
String, dynamic> ? -
Parameters to be sent with the API request.
getter/setter pair
- requestType ↔ HTTPRequestType
-
Type of the HTTP request (e.g., POST, GET, DELETE, PUT).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceName ↔ String
-
Name of the service or API being called (used for debugging purposes).
getter/setter pair
- timeSecond ↔ int
-
Timeout duration for the API call.
getter/setter pair
- url ↔ String
-
The endpoint URL for the API call.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited