AlertInfo class
Represents alert information with a title and message.
This class is used to encapsulate user-friendly error messages that can be displayed as alerts to the user.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited