ApiCall class
A utility class responsible for making API calls and handling exceptions.
This class provides methods to make both regular and multipart API calls. It also handles various types of exceptions that can occur during the API call process.
Constructors
- ApiCall()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
callService(
{required APIRequestInfoObj requestInfo}) → Future< Response> - Makes an API call based on the provided request information.