underMaintenanceMessage constant
String
const underMaintenanceMessage
Message indicating the system is down for scheduled maintenance.
Implementation
static const String underMaintenanceMessage =
"Sorry, we're down for scheduled maintenance right now, please try after some time.";